@@ -2,19 +2,12 @@
 package MooseX::AttributeHelpers::Collection::Hash;
 use Moose;
 
-our $VERSION   = '0.12_01';
+our $VERSION   = '0.17';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
-use MooseX::AttributeHelpers::MethodProvider::Hash;
-
-extends 'MooseX::AttributeHelpers::Collection';
-
-has '+method_provider' => (
-    default => 'MooseX::AttributeHelpers::MethodProvider::Hash'
-);
-
-sub helper_type { 'HashRef' }
+extends 'Moose::Meta::Attribute';
+with 'MooseX::AttributeHelpers::Trait::Collection::Hash';
 
 no Moose;
 
@@ -39,7 +32,7 @@ MooseX::AttributeHelpers::Collection::Hash
   package Stuff;
   use Moose;
   use MooseX::AttributeHelpers;
-  
+
   has 'options' => (
       metaclass => 'Collection::Hash',
       is        => 'ro',
@@ -47,16 +40,16 @@ MooseX::AttributeHelpers::Collection::Hash
       default   => sub { {} },
       provides  => {
           'set'    => 'set_option',
-          'get'    => 'get_option',            
+          'get'    => 'get_option',
           'empty'  => 'has_options',
           'count'  => 'num_options',
           'delete' => 'delete_option',
       }
   );
-  
+
 =head1 DESCRIPTION
 
-This module provides an Hash attribute which provides a number of 
+This module provides a Hash attribute which provides a number of
 hash-like operations. See L<MooseX::AttributeHelpers::MethodProvider::Hash>
 for more details.
 
@@ -76,7 +69,7 @@ for more details.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -86,7 +79,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
