@@ -1,55 +1,13 @@
 package MooseX::AttributeHelpers::Number;
 use Moose;
 
-our $VERSION   = '0.12_01';
+our $VERSION   = '0.17';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'MooseX::AttributeHelpers::Base';
+extends 'Moose::Meta::Attribute';
+with 'MooseX::AttributeHelpers::Trait::Number';
 
-sub helper_type { 'Num' }
-
-# NOTE:
-# we don't use the method provider for this 
-# module since many of the names of the provied
-# methods would conflict with keywords
-# - SL
-
-has '+method_constructors' => (
-    default => sub {
-        return +{
-            set => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $_[1]) };
-            },
-            add => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $reader->($_[0]) + $_[1]) };
-            },
-            sub => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $reader->($_[0]) - $_[1]) };
-            },
-            mul => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $reader->($_[0]) * $_[1]) };
-            },
-            div => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $reader->($_[0]) / $_[1]) };
-            },
-            mod => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], $reader->($_[0]) % $_[1]) };
-            },
-            abs => sub {
-                my ($attr, $reader, $writer) = @_;
-                return sub { $writer->($_[0], abs($reader->($_[0])) ) };
-            },
-        }
-    }
-);
-    
 no Moose;
 
 # register the alias ...
@@ -157,7 +115,7 @@ Robert Boone
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
